@@ -7,6 +7,9 @@ pub(self) mod lsof;
 #[cfg(any(target_os = "macos", target_os = "freebsd"))]
 mod lsof_utils;
 
+#[cfg(target_os = "windows")]
+pub(self) mod windows;
+
 mod errors;
 mod shared;
 
