@@ -1,11 +1,11 @@
 use ::async_trait::async_trait;
+use ::crossterm::event::Event;
 use ::ipnetwork::IpNetwork;
 use ::pnet::datalink::DataLinkReceiver;
 use ::pnet::datalink::NetworkInterface;
 use ::std::collections::HashMap;
 use ::std::net::{IpAddr, Ipv4Addr, SocketAddr};
 use ::std::{thread, time};
-use ::termion::event::Event;
 use ::tokio::runtime::Runtime;
 
 use crate::{
@@ -141,7 +141,6 @@ pub fn get_open_sockets() -> OpenSockets {
 
     OpenSockets {
         sockets_to_procs: local_socket_to_procs,
-        connections,
     }
 }
 
